@@ -286,8 +286,9 @@ check_maildir(Mailbox *mbox)
 			{
 			mbox->mail_count++;
 			if (   unseen_is_new
-				&& (s = strchr(name, ':')) != NULL
-				&& !strchr(s, 'S')
+				&& (   (s = strchr(name, ':')) == NULL
+					|| !strchr(s, 'S')
+				   )
 			   )
 				mbox->new_mail_count++;
 			}
