@@ -1660,11 +1660,9 @@ typedef struct
 	gboolean	changed;
 	gint		type;
 
-	gchar		*dir;			/* Optional convenience prefix for basename */
-	gchar		*path;			/* Constructed from dir and basename and    */
-								/*  passed to get sensor functions */
+	gchar		*path;			/* Pathname to sensor data or device file */
 
-	gchar		*basename;		/* These 4 are unique sensor identification */
+	gchar		*id_name;		/* These 4 are unique sensor identification */
 	gint		id;				/*   of a particular sensor type */
 	gint		iodev;			/* One or any combination may be used. */
 	gint		inter;
@@ -1734,40 +1732,31 @@ gkrellm_sensors_update_volt_order_base(void)
 	{
 	}
 
-  /* A sensor within a type is uniquely identified by its basename.
+  /* A sensor within a type is uniquely identified by its id_name.
   |  A sysdep interface may additionally use any of the triple integer
   |  set (id, iodev, inter) for internal identification.
-  |  The "dir" arg is an optional common path prefix to basename which
-  |  is used to construct the sensor->path value.  As a convenience to the
-  |  sysdep code, the path value instead of basename is passed to the
-  |  get_temperature, get_fan, and get_voltage functions.  So the monitor
-  |  code here uses path to read the sensor values, but basename is only
+  |  Monitor code here uses path to read the sensor values, but id_name is only
   |  passed to the client since that is all that is needed for identification
   |  (the client is no longer interfacing to sysdep code).
   */
 void
-gkrellm_sensors_add_sensor(gint type, gchar *dir, gchar *basename,
+gkrellm_sensors_add_sensor(gint type, gchar *sensor_path, gchar *id_name,
 		gint id, gint iodev, gint inter,
 		gfloat factor, gfloat offset, gchar *vref, gchar *default_label)
 	{
 	Sensor	*sensor;
 
-	if (!basename || !*basename || type < 0 || type > 2)
+	if (!id_name || !*id_name || type < 0 || type > 2)
 		return;
 
 	sensor = g_new0(Sensor, 1);
-	sensor->basename = g_strdup(basename);
+	sensor->id_name = g_strdup(id_name);
 
-	if (dir)
-		{
-		sensor->dir = g_strdup(dir);
-		sensor->path = g_strdup_printf("%s/%s", dir, basename);
-		}
+	if (sensor_path)
+		sensor->path = g_strdup(sensor_path);
 	else
-		{
-		sensor->dir = g_strdup("NONE");
-		sensor->path = g_strdup(basename);
-		}
+		sensor->path = g_strdup(id_name);
+
 	sensor->vref = g_strdup(vref ? vref : "NONE");
 	sensor->default_label = g_strdup(default_label ? default_label : "NONE");
 
@@ -1807,7 +1796,7 @@ serve_sensors_data(GkrellmdClient *client)
 		if (sr->changed || !client->served)
 			{
 			sprintf(buf, "%d \"%s\" %d %d %d %.2f\n",
-					sr->type, sr->basename,
+					sr->type, sr->id_name,
 					sr->id, sr->iodev, sr->inter, sr->raw_value);
 			d = g_strconcat(s, buf, NULL);
 			g_free(s);
@@ -1829,7 +1818,7 @@ serve_sensors_setup(GkrellmdClient *client)
 		{
 		s = (Sensor *) list->data;
 		sprintf(buf, "%d \"%s\" %d %d %d %.4f %.4f \"%s\" \"%s\"\n",
-				s->type, s->basename,
+				s->type, s->id_name,
 				s->id, s->iodev, s->inter,
 				s->factor, s->offset, s->vref, s->default_label);
 		gkrellmd_send_to_client(client, buf);
