@@ -321,55 +321,68 @@ check_low_alarm_limit(GkrellmAlert *alert, gfloat value)
 void
 gkrellm_check_alert(GkrellmAlert *alert, gfloat value)
 	{
+	GList					*plist;
+	GkrellmAlertPlugin		*gap;
+	GkrellmAlertPluginLink	*apl;
+
 	if (!alert || !alert->activated || alert->freeze || !_GK.initialized)
 		return;
-	if (alert->delay > 0 && !GK.second_tick)
-		return;
 
-	if (alert->check_low)
+	if (alert->delay == 0 || GK.second_tick)
 		{
-		if (check_low_alarm_limit(alert, value))
-			{				
-			stop_alarm(alert, &alert->high);
-			stop_warn(alert, &alert->high);
-			stop_warn(alert, &alert->low);
-			trigger_alarm(alert, &alert->low);
-			}
-		else
+		if (alert->check_low)
 			{
-			stop_alarm(alert, &alert->low);
-			if (check_low_warn_limit(alert, value))
-				{
+			if (check_low_alarm_limit(alert, value))
+				{				
 				stop_alarm(alert, &alert->high);
 				stop_warn(alert, &alert->high);
-				trigger_warn(alert, &alert->low);
+				stop_warn(alert, &alert->low);
+				trigger_alarm(alert, &alert->low);
 				}
 			else
-				stop_warn(alert, &alert->low);
-			}
-		}
-	if (alert->check_high)
-		{
-		if (check_high_alarm_limit(alert, value))
-			{
-			stop_warn(alert, &alert->high);
-			stop_warn(alert, &alert->low);
-			stop_alarm(alert, &alert->low);
-			trigger_alarm(alert, &alert->high);
-			}
-		else
-			{
-			stop_alarm(alert, &alert->high);
-			if (check_high_warn_limit(alert, value))
 				{
+				stop_alarm(alert, &alert->low);
+				if (check_low_warn_limit(alert, value))
+					{
+					stop_alarm(alert, &alert->high);
+					stop_warn(alert, &alert->high);
+					trigger_warn(alert, &alert->low);
+					}
+				else
+					stop_warn(alert, &alert->low);
+				}
+			}
+		if (alert->check_high)
+			{
+			if (check_high_alarm_limit(alert, value))
+				{
+				stop_warn(alert, &alert->high);
 				stop_warn(alert, &alert->low);
 				stop_alarm(alert, &alert->low);
-				trigger_warn(alert, &alert->high);
+				trigger_alarm(alert, &alert->high);
 				}
 			else
-				stop_warn(alert, &alert->high);
+				{
+				stop_alarm(alert, &alert->high);
+				if (check_high_warn_limit(alert, value))
+					{
+					stop_warn(alert, &alert->low);
+					stop_alarm(alert, &alert->low);
+					trigger_warn(alert, &alert->high);
+					}
+				else
+					stop_warn(alert, &alert->high);
+				}
 			}
 		}
+
+	for (plist = alert->plugin_list; plist; plist = plist->next)
+		{
+		apl = (GkrellmAlertPluginLink *) plist->data;
+		gap = apl->alert_plugin;
+		if (MONITOR_ENABLED(gap->mon) && gap->check_func)
+			(*gap->check_func)(alert, apl->data, value);
+		}
 	}
 
 void
@@ -729,13 +742,15 @@ gkrellm_alert_plugin_add(GkrellmMonitor *mon, gchar *name)
 	}
 
 void
-gkrellm_alert_plugin_connect(GkrellmAlertPlugin *gap,
+gkrellm_alert_plugin_alert_connect(GkrellmAlertPlugin *gap,
 			void (*alarm_func)(), void (*warn_func)(),
-			void (*update_func)(), void (*destroy_func)())
+			void (*update_func)(), void (*check_func)(),
+			void (*destroy_func)())
 	{
 	gap->alarm_func = alarm_func;
 	gap->warn_func = warn_func;
 	gap->update_func = update_func;
+	gap->check_func = check_func;
 	gap->destroy_func = destroy_func;
 	}
 
