@@ -52,10 +52,14 @@
 #endif
 #endif
 
-#if defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__OpenBSD__)
 #define HAVE_GETADDRINFO	1
 #endif
 
+#if defined(__NetBSD__)
+#define HAVE_GETADDRINFO    1
+#endif
+
 #if defined(__solaris__)
 # include <netconfig.h>
 # if defined(NC_INET6)
