@@ -1643,7 +1643,11 @@ parse_monitor_config_keyword(gchar *line)
 		while (*line == ' ' || *line == '\t')
 			++line;
 		if (*line && mon->load_user_config && mon->privat->enabled)
+			{
+			gkrellm_record_state(LOAD_CONFIG, mon);
 			(*(mon->load_user_config))(line);
+			gkrellm_record_state(INTERNAL, NULL);
+			}
 		result = TRUE;
 		}
 	g_free(keyword);
@@ -2441,7 +2445,11 @@ save_user_config(void)
 		{
 		mon = (GkrellmMonitor *) list->data;
 		if (mon->save_user_config && mon->privat->enabled)
+			{
+			gkrellm_record_state(SAVE_CONFIG, mon);
 			(*(mon->save_user_config))(f);
+			gkrellm_record_state(INTERNAL, NULL);
+			}
 		}
 #if defined (S_IRUSR)
 	mode = (S_IRUSR | S_IWUSR);
