@@ -78,10 +78,14 @@ gkrellm_locale_dup_string(gchar **dst_utf8, gchar *src, gchar **dst_locale)
 			{
 			*dst_utf8 = g_strdup(src);
 			*dst_locale = g_locale_from_utf8(src, -1, NULL, NULL, NULL);
+			if (!*dst_locale)
+				*dst_locale = g_strdup(src);
 			}
 		else
 			{
 			*dst_utf8 = g_locale_to_utf8(src, -1, NULL, NULL, NULL);
+			if (!*dst_utf8)
+				*dst_utf8 = g_strdup(src);
 			*dst_locale = g_strdup(src);
 			}
 		}
