@@ -35,7 +35,8 @@
 
 typedef struct
 	{
-	gchar			*name;
+	gchar			*name,
+					*label;			/* Possibly translated name */
 	GtkWidget		*vbox;
 	GtkWidget		*enable_button;
 	GkrellmChart	*chart;
@@ -110,25 +111,34 @@ lookup_disk_by_name(gchar *name)
 		disk = (DiskMon * ) list->data;
 		if (!strcmp(name, disk->name))
 			return disk;
+
+		/* Pre 2.1.15 config compatibility where translated "Disk" was
+		|  written into the config.  XXX remove this eventually.
+		*/
+		if (   (disk == composite_disk || assign_method == DISK_ASSIGN_NTH)
+			&& !strcmp(name, disk->label))
+			return disk;
 		}
 	return NULL;
 	}
 
 static DiskMon *
-new_disk(gchar *name)
+disk_new(gchar *name, gchar *label)
 	{
 	DiskMon	*disk;
 
 	disk = g_new0(DiskMon, 1);
 	disk->name = g_strdup(name);
+	disk->label = g_strdup(label);
 	disk->launch.command = g_strdup("");
 	disk->launch.tooltip_comment = g_strdup("");
 	disk->alert_uses_read = disk->alert_uses_write = TRUE;
+	disk->extra_info = TRUE;
 	return disk;
 	}
 
 static DiskMon *
-add_disk(gchar *name, gint major, gint minor, gint order)
+add_disk(gchar *name, gchar *label, gint major, gint minor, gint order)
 	{
 	DiskMon	*disk;
 	GList	*list;
@@ -136,7 +146,7 @@ add_disk(gchar *name, gint major, gint minor, gint order)
 
 	if (lookup_disk_by_name(name))
 		return NULL;
-	disk = new_disk(name);
+	disk = disk_new(name, label);
 
 	disk->major = major;
 	disk->minor = minor;
@@ -170,7 +180,7 @@ add_subdisk(gchar *subdisk_name, gchar *disk_name, gint subdisk)
 		}
 	if (!list)
 		return NULL;
-	sdisk = new_disk(subdisk_name);
+	sdisk = disk_new(subdisk_name, subdisk_name);
 	sdisk->order = disk->order;
 	sdisk->subdisk = subdisk;
 	for (list = list->next; list; list = list->next)
@@ -252,7 +262,7 @@ gkrellm_disk_assign_data_by_device(gint device_number, gint unit_number,
 		{
 		name = (*name_from_device)(device_number, unit_number, &order);
 		if (name)
-			disk = add_disk(name, device_number, unit_number, order);
+			disk = add_disk(name, name, device_number, unit_number, order);
 		}
 	disk_assign_data(disk, rb, wb);
 	}
@@ -261,15 +271,16 @@ void
 gkrellm_disk_assign_data_nth(gint n, guint64 rb, guint64 wb)
 	{
 	DiskMon	*disk;
-	gchar	name[32];
+	gchar	name[32], label[32];
 
 	assign_method = DISK_ASSIGN_NTH;
 	if (n < n_disks)
 		disk = (DiskMon *) g_list_nth_data(disk_mon_list, n + 1);
 	else
 		{
-		sprintf(name, "%s%c", _("Disk"), 'A' + n);
-		disk = add_disk(name, 0, 0, n);
+		sprintf(name, "%s%c", "Disk", 'A' + n);
+		sprintf(label, "%s%c", _("Disk"), 'A' + n);
+		disk = add_disk(name, label, 0, 0, n);
 		}
 	disk_assign_data(disk, rb, wb);
 	}
@@ -288,7 +299,7 @@ gkrellm_disk_assign_data_by_name(gchar *name, guint64 rb, guint64 wb)
 		{
 		if (order_from_name)
 			order = (*order_from_name)(name);
-		disk = add_disk(name, 0, 0, order);
+		disk = add_disk(name, name, 0, 0, order);
 		}
 	disk_assign_data(disk, rb, wb);
 	}
@@ -319,6 +330,10 @@ gkrellm_disk_subdisk_assign_data_by_name(gchar *subdisk_name, gchar *disk_name,
 	disk_assign_data(disk, rb, wb);
 	}
 
+
+/* ----------- End of Disk monitor to system dependent interface ---------- */
+
+
 static GkrellmSizeAbbrev	disk_blocks_abbrev[]	=
 	{
 	{ KB_SIZE(1),		1,				"%.0f" },
@@ -593,7 +608,7 @@ create_disk_monitor(DiskMon *disk, gint first_create)
 
 	setup_disk_scaling(cp->config, cp);
 
-	gkrellm_panel_configure(p, disk->name, style);
+	gkrellm_panel_configure(p, disk->label, style);
 	gkrellm_panel_create(disk->vbox, mon_disk, p);
 	disk->enabled = TRUE;
 
@@ -704,21 +719,50 @@ create_alert(DiskMon *disk)
 				cb_command_process, disk);
 	}
 
-static void
-save_disk_config(FILE *f)
+static gboolean
+any_enabled_subdisks(GList *dlist)
 	{
 	GList	*list;
 	DiskMon	*disk;
 
+	for (list = dlist; list; list = list->next)
+		{
+		disk = (DiskMon *) list->data;
+		if (disk->subdisk == -1)
+			break;
+		if (disk->enabled)
+			return TRUE;
+		}
+	return FALSE;
+	}
+
+static void
+save_disk_config(FILE *f)
+	{
+	GList		*list;
+	DiskMon		*disk;
+	gboolean	have_enabled_subdisks;
+
 	if (n_disks == 0)
 		return;
 	fprintf(f, "%s assign_method %d\n", DISK_CONFIG_KEYWORD, assign_method);
 	for (list = disk_mon_list; list; list = list->next)
 		{
 		disk = (DiskMon *) list->data;
-		fprintf(f, "%s device %s %d %d %d %d %d %d\n", DISK_CONFIG_KEYWORD,
+
+		/* To deal with possible disk hardware/partition changes at next load
+		|  of the config, record if any subdisks are enabled to determine if
+		|  a disk saved into the config here should be artificially created
+		|  should it not be present at next gkrellm startup.
+		*/
+		have_enabled_subdisks = (disk->subdisk == -1) ? 
+					any_enabled_subdisks(list->next) : FALSE;
+
+		fprintf(f, "%s device %s %d %d %d %d %d %d %d\n",
+					DISK_CONFIG_KEYWORD,
 					disk->name, disk->major, disk->minor, disk->order,
-					disk->enabled, disk->extra_info, disk->subdisk);
+					disk->enabled, disk->extra_info, disk->subdisk,
+					have_enabled_subdisks);
 		if (*(disk->launch.command) != '\0')
 			fprintf(f, "%s launch %s %s\n", DISK_CONFIG_KEYWORD,
 						disk->name, disk->launch.command);
@@ -742,10 +786,13 @@ save_disk_config(FILE *f)
 static void
 load_disk_config(gchar *arg)
 	{
-	DiskMon		*disk;
+	DiskMon		*disk = NULL;
 	gchar		config[32], item[CFG_BUFSIZE],
 				name[32], item1[CFG_BUFSIZE];
-	gint		major, minor, n, extra, order, subdisk = -1;
+	gint		major, minor, enabled, extra, order, subdisk = -1;
+	gint		n;
+	gboolean	enabled_subdisks = TRUE;
+	static gchar *parent;
 	static gint	config_assign_method;
 
 	n = sscanf(arg, "%31s %[^\n]", config, item);
@@ -755,67 +802,62 @@ load_disk_config(gchar *arg)
 			gkrellm_locale_dup_string(&text_format, item, &text_format_locale);
 		else if (!strcmp(config, "assign_method"))
 			sscanf(item, "%d", &config_assign_method);
-		else if (!strcmp(config, "device"))
+		else if (sscanf(item, "%31s %[^\n]", name, item1) == 2)
+			disk = lookup_disk_by_name(name);
+
+		if (!strcmp(config, "device"))
 			{
 			/* Disk config can be invalid (different disk naming scheme)
 			|  if user changes kernel version.
 			*/
 			if (   config_assign_method == assign_method
-				&& sscanf(item, "%31s %d %d %d %d %d %d", name,
-						&major, &minor, &order, &n, &extra, &subdisk) >= 6
+				&& sscanf(item1, "%d %d %d %d %d %d %d",
+							&major, &minor, &order,
+							&enabled, &extra,
+							&subdisk, &enabled_subdisks) >= 5
 			   )
 				{
-				/* The list of Linux disks reported can change as disks are
-				|  mounted for the first time, so a disk may not be added when
-				|  the config is read.  So add them from the config.  Except
-				|  for subdisks.
+				/* A disk in the config may not have been found in the above
+				|  lookup because of removable drives or hardware/partition
+				|  changes since last gkrellm run.
+				|  Also Linux <= 2.4 may be getting disk stats from /proc/stat
+				|  where disks won't appear until they have I/O.
+				|  So, artificially create these not present disks if they
+				|  were previously enabled.
 				*/
-				if (   (disk = lookup_disk_by_name(name)) == NULL
-					&& subdisk == -1
+				if (subdisk == -1)
+					gkrellm_dup_string(&parent, name);
+				if (   !disk && subdisk == -1
+					&& (enabled || enabled_subdisks)
 				   )
-					disk = add_disk(name, major, minor, order - 1);
+					disk = add_disk(name, name, major, minor, order - 1);
+				else if (!disk && subdisk >= 0 && enabled)
+					disk = add_subdisk(name, parent, subdisk);
 				if (disk)
 					{
-					disk->enabled = n;
+					disk->enabled = enabled;
 					disk->extra_info = extra;
 					}
 				}
+			return;
 			}
-		else if (!strcmp(config, GKRELLM_CHARTCONFIG_KEYWORD))
-			{
-			sscanf(item, "%31s %[^\n]", name, item1);
-			if ((disk = lookup_disk_by_name(name)) != NULL)
-				gkrellm_load_chartconfig(&disk->chart_config, item1, 2);
-			}
+		if (!disk)
+			return;
+		if (!strcmp(config, GKRELLM_CHARTCONFIG_KEYWORD))
+			gkrellm_load_chartconfig(&disk->chart_config, item1, 2);
 		else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 			{
-			sscanf(item, "%31s %[^\n]", name, item1);
-			if ((disk = lookup_disk_by_name(name)) != NULL)
-				{
-				if (!disk->alert)
-					create_alert(disk);
-				gkrellm_load_alertconfig(&disk->alert, item1);
-				}
+			if (!disk->alert)
+				create_alert(disk);
+			gkrellm_load_alertconfig(&disk->alert, item1);
 			}
 		else if (!strcmp(config, "extra_alert_config"))
-			{
-			sscanf(item, "%31s %[^\n]", name, item1);
-			if ((disk = lookup_disk_by_name(name)) != NULL)
-				sscanf(item1, "%d %d",
+			sscanf(item1, "%d %d",
 							&disk->alert_uses_read, &disk->alert_uses_write);
-			}
-		else if (strcmp(config, "launch") == 0)
-			{
-			sscanf(item, "%31s %[^\n]", name, item1);
-			if ((disk = lookup_disk_by_name(name)) != NULL)
-				disk->launch.command = g_strdup(item1);
-			}
-		else if (strcmp(config, "tooltip_comment") == 0)
-			{
-			sscanf(item, "%31s %[^\n]", name, item1);
-			if ((disk = lookup_disk_by_name(name)) != NULL)
-				disk->launch.tooltip_comment = g_strdup(item1);
-			}
+		else if (!strcmp(config, "launch"))
+			disk->launch.command = g_strdup(item1);
+		else if (!strcmp(config, "tooltip_comment"))
+			disk->launch.tooltip_comment = g_strdup(item1);
 		}
 	}
 
@@ -869,7 +911,7 @@ create_model(void)
 		else
 			{
 			gtk_tree_store_set(tree, &iter,
-					NAME_COLUMN, disk->name,
+					NAME_COLUMN, disk->label,
 					ENABLE_COLUMN, disk->enabled,
 					DISK_COLUMN, disk,
 					-1);
@@ -911,7 +953,7 @@ add_launch_entry(GtkWidget *vbox, DiskMon *disk)
 	{
 	disk->launch_table = gkrellm_gtk_launcher_table_new(vbox, 1);
 	gkrellm_gtk_config_launcher(disk->launch_table, 0,  &disk->launch_entry,
-				&disk->tooltip_entry, disk->name,
+				&disk->tooltip_entry, disk->label,
 				&disk->launch);
 	g_signal_connect(G_OBJECT(disk->launch_entry), "changed",
 				G_CALLBACK(cb_launch_entry), disk);
@@ -1118,9 +1160,9 @@ static gchar	*disk_info_text[] =
 N_("<h>Chart Labels\n"),
 N_("Substitution variables for the format string for chart labels:\n"),
 N_("\t$M    maximum chart value\n"),
-N_("\t$T    total read blocks + write blocks\n"),
-N_("\t$r    read blocks\n"),
-N_("\t$w    write blocks\n"),
+N_("\t$T    total read bytes + write bytes\n"),
+N_("\t$r    read bytes\n"),
+N_("\t$w    write bytes\n"),
 "\n",
 N_("Substitution variables may be used in alert commands.\n")
 };
@@ -1263,11 +1305,10 @@ GkrellmMonitor *
 init_disk_monitor(void)
 	{
 	DiskMon	*disk;
-	GList	*list;
 
 	monitor_disk.name = _(monitor_disk.name);
 
-	disk = new_disk(_("Disk"));
+	disk = disk_new("Disk", _("Disk"));
 	disk_mon_list = g_list_append(disk_mon_list, disk);
 
 	composite_disk = disk;
@@ -1277,12 +1318,6 @@ init_disk_monitor(void)
 
 	if (setup_disk_interface())
 		{
-		for (list = disk_mon_list->next; list; list = list->next)
-			{
-			disk = (DiskMon *) list->data;
-			disk->enabled = FALSE;
-			disk->extra_info = TRUE;
-			}
 		if (n_disks > 0)
 			composite_disk->enabled = TRUE;
 		style_id = gkrellm_add_chart_style(&monitor_disk, DISK_STYLE_NAME);
