@@ -2046,7 +2046,11 @@ apply_config(void)
 		if (   mon->apply_config && mon->privat->enabled
 			&& (mon->privat->config_created || !mon->create_config)
 		   )
+			{
+			gkrellm_record_state(APPLY_CONFIG, mon);
 			(*(mon->apply_config))();
+			gkrellm_record_state(INTERNAL, NULL);
+			}
 		}
 	gkrellm_thaw_side_frame_packing();
 	gkrellm_config_modified();
@@ -2090,7 +2094,11 @@ real_create_config(GkrellmMonitor *mon)
 	{
 	if (mon->privat->config_created || !mon->create_config)
 		return;
+
+	gkrellm_record_state(CREATE_CONFIG, mon);
 	(*(mon->create_config))(mon->privat->config_vbox);
+	gkrellm_record_state(INTERNAL, NULL);
+
 	gtk_widget_show_all(mon->privat->config_vbox);
 	mon->privat->config_created = TRUE;
 	}
@@ -2184,8 +2192,11 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
 		return;
 	if (selected_monitor && selected_monitor->apply_config)
+		{
+		gkrellm_record_state(APPLY_CONFIG, selected_monitor);
 		(*(selected_monitor->apply_config))();
-
+		gkrellm_record_state(INTERNAL, NULL);
+		}
 	gtk_tree_model_get(model, &iter,
 				MONITOR_COLUMN, &selected_monitor,
 				PAGE_COLUMN, &page,
