@@ -269,13 +269,17 @@ format_chart_text(InetMon *in, gchar *src_string, gchar *buf, gint size)
 				sscanf(s + 2, "%d%n", &n, &i);
 				s += i;
 				--n;
-				if (n > w)
+				if (n > w || n < 0)
 					n = w;
-				list = in->chart_minute->cd_list;
+				list = in->hour_mode ?
+						in->chart_hour->cd_list : in->chart_minute->cd_list;
 				cd = (GkrellmChartdata *) list->data;
 				if (*in->label0)
-					for (value = in->hits0_minute; n > 0; --n)
+					{
+					value = in->hour_mode ? in->hits0_hour : in->hits0_minute;
+					for ( ; n > 0; --n)
 						value += gkrellm_get_chartdata_data(cd, w - n);
+					}
 				}
 			else if (c == 'A' && *in->label1)
 				value = in->active1;
@@ -287,15 +291,19 @@ format_chart_text(InetMon *in, gchar *src_string, gchar *buf, gint size)
 				sscanf(s + 2, "%d%n", &n, &i);
 				s += i;
 				--n;
-				if (n > w)
+				if (n > w || n < 0)
 					n = w;
-				list = in->chart_minute->cd_list;
+				list = in->hour_mode ?
+						in->chart_hour->cd_list : in->chart_minute->cd_list;
 				if (list->next)
 					list = list->next;
 				cd = (GkrellmChartdata *) list->data;
 				if (*in->label1)
-					for (value = in->hits1_minute; n > 0; --n)
+					{
+					value = in->hour_mode ? in->hits1_hour : in->hits1_minute;
+					for ( ; n > 0; --n)
 						value += gkrellm_get_chartdata_data(cd, w - n);
+					}
 				}
 			if (value >= 0)
 				len = snprintf(buf, size, "%d", value);
@@ -1775,10 +1783,10 @@ N_("<h>Chart Labels\n"),
 N_("Substitution variables for the format string for chart labels:\n"),
 N_("\t$M    maximum chart value\n"),
 N_("\t$a    current active connections for Data0\n"),
-N_("\t$cN   total connections in last N minutes for Data0\n"),
+N_("\t$cN   total connections in last N minutes (or hours) for Data0\n"),
 N_("\t$l    label for Data0\n"),
 N_("\t$A    current active connections for Data1\n"),
-N_("\t$CN   total connections in last N minutes for Data1\n"),
+N_("\t$CN   total connections in last N minutes (or hours) for Data1\n"),
 N_("\t$L    label for Data1\n"),
 
 "\n",
