@@ -329,9 +329,11 @@ update_monitors()
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
 		mon = (GkrellmMonitor *) list->data;
+		gkrellm_record_state(UPDATE_MONITOR, mon);
 		if (mon->update_monitor && mon->privat->enabled)
 			(*(mon->update_monitor))();
 		}
+	gkrellm_record_state(INTERNAL, NULL);
 	++GK.timer_ticks;
 
 	if (save_position_countdown > 0 && --save_position_countdown == 0)
@@ -1556,7 +1558,15 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 
 	gdk_window_get_geometry(NULL, NULL, NULL, &_GK.w_display,
 				&_GK.h_display, NULL);
+
+#if !defined(WIN32)
 	gdk_window_get_position(widget->window, &x, &y);
+#else
+	/* Windows Gtk bug? */
+	x = ev->x;
+	y = ev->y;
+#endif
+
 	gdk_drawable_get_size(gtree.window->window, &w, &h);
 
 	w_gkrellm = _GK.chart_width + _GK.frame_left_width + _GK.frame_right_width;
@@ -1573,7 +1583,7 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 		w = w_gkrellm;
 		h = h_gkrellm;
 		}
-	size_change = (w != w_prev) | (h != w_prev);
+	size_change = (w != w_prev) | (h != h_prev);
 	position_change = (x != x_prev) | (y != y_prev);
 
 	if (size_change)
@@ -1776,6 +1786,7 @@ build_gkrellm()
 				}
 			if (mon->create_monitor && mon->privat->enabled)
 				{
+				gkrellm_record_state(CREATE_MONITOR, mon);
 				gtk_widget_show(mon->privat->vbox);
 				gtk_widget_show(mon->privat->main_vbox);
 				render_monitor_spacers(mon);
@@ -1783,6 +1794,7 @@ build_gkrellm()
 							mon->privat->created ? FALSE : TRUE);
 				mon->privat->created = TRUE;
 				}
+			gkrellm_record_state(INTERNAL, NULL);
 			}
 		}
 	create_frame_bottom(gtree.bottom_vbox);
@@ -1876,6 +1888,61 @@ _signal_quit(gint sig)
 	gkrellm_exit(1);
 	}
 
+void
+gkrellm_record_state(enum GkrellmState state, GkrellmMonitor *mon)
+	{
+	_GK.gkrellm_state = state;
+	_GK.active_monitor = mon;
+	}
+
+static void
+gkrellm_abort(gint sig)
+	{
+	gchar			*fault,
+					*state,
+					buf[512];
+	gboolean		do_xmessage = TRUE;
+	GkrellmMonitor	*mon 	= _GK.active_monitor;
+
+	if (sig == SIGSEGV)
+		fault = _("segmentation fault");
+	else if (sig == SIGFPE)
+		fault = _("floating point exception");
+	else
+		fault = _("aborted");
+
+	if (_GK.gkrellm_state == INITIALIZING)
+		state = _("initializing");
+	else if (_GK.gkrellm_state == INIT_MONITOR)
+		state = "init_monitor";
+	else if (_GK.gkrellm_state == CREATE_MONITOR)
+		state = "create_monitor";
+	else if (_GK.gkrellm_state == UPDATE_MONITOR)
+		state = "update_monitor";
+	else if (_GK.gkrellm_state == CREATE_CONFIG)
+		state = "create_config";
+	else if (_GK.gkrellm_state == LOAD_CONFIG)
+		state = "load_user_config";
+	else if (_GK.gkrellm_state == SAVE_CONFIG)
+		state = "save_user_config";
+	else if (_GK.gkrellm_state == APPLY_CONFIG)
+		state = "apply_config";
+	else
+		{
+		state = "?";
+		do_xmessage = FALSE;
+		}
+
+	snprintf(buf, sizeof(buf), "xmessage gkrellm %s:  %s  (%s)", fault,
+				(mon && mon->name) ? mon->name : "", state);
+	printf("%s\n", buf + 9);
+	if (do_xmessage)
+		g_spawn_command_line_async(buf, NULL);
+
+	signal(SIGABRT, SIG_DFL);
+	abort();
+	}
+
 static void
 setup_signal_handler(void)
 	{
@@ -1931,7 +1998,12 @@ main(gint argc, gchar **argv)
 
 	_GK.start_time = time(0);
 	gkrellm_current_tm = *(localtime(&_GK.start_time));
+
 	_GK.initialized = FALSE;
+	gkrellm_record_state(INITIALIZING, NULL);
+	signal(SIGFPE, gkrellm_abort);
+	signal(SIGSEGV, gkrellm_abort);
+	signal(SIGABRT, gkrellm_abort);
 
 	g_set_print_handler(gkrellm_print);
 
