@@ -180,7 +180,7 @@ gkrellm_panel_configure(GkrellmPanel *p, gchar *string, GkrellmStyle *style)
 	}
 
 static void
-draw_panel(GkrellmPanel *p, gint to_screen)
+draw_panel_label(GkrellmPanel *p, gboolean to_bg)
 	{
 	GkrellmLabel		*lbl	= p->label;
 	GkrellmTextstyle	*ts		= p->textstyle;
@@ -188,12 +188,6 @@ draw_panel(GkrellmPanel *p, gint to_screen)
 	gchar				*s;
 	gint				xdst;
 
-	if (!gkrellm_winop_draw_rootpixmap_onto_transparent_panel(p))
-		gdk_draw_drawable(p->bg_pixmap, _GK.draw1_GC, p->bg_clean_pixmap,
-					0, 0, 0, 0, p->w, p->h);
-
-	gdk_draw_drawable(p->pixmap, _GK.draw1_GC, p->bg_pixmap,
-					0, 0, 0, 0, p->w, p->h);
 	if (   lbl && ts
 		&& ((s = lbl->string) != NULL)
 		&& lbl->position >= 0
@@ -204,8 +198,21 @@ draw_panel(GkrellmPanel *p, gint to_screen)
 		xdst = x_label_position(lbl->position, p->w, lbl->width, m->left);
 		lbl->x_panel = xdst;
 		gkrellm_draw_string(p->pixmap, ts, xdst, lbl->y_baseline, s);
-		gkrellm_draw_string(p->bg_pixmap, ts, xdst, lbl->y_baseline, s);
+		if (to_bg)
+			gkrellm_draw_string(p->bg_pixmap, ts, xdst, lbl->y_baseline, s);
 		}
+	}
+
+static void
+draw_panel(GkrellmPanel *p, gint to_screen)
+	{
+	if (!gkrellm_winop_draw_rootpixmap_onto_transparent_panel(p))
+		gdk_draw_drawable(p->bg_pixmap, _GK.draw1_GC, p->bg_clean_pixmap,
+					0, 0, 0, 0, p->w, p->h);
+
+	gdk_draw_drawable(p->pixmap, _GK.draw1_GC, p->bg_pixmap,
+					0, 0, 0, 0, p->w, p->h);
+	draw_panel_label(p, TRUE);
 	if (p->drawing_area->window && to_screen)
 		{
 		gdk_draw_drawable(p->drawing_area->window, _GK.draw1_GC, p->pixmap,
@@ -214,10 +221,18 @@ draw_panel(GkrellmPanel *p, gint to_screen)
 		}
 	}
 
+void
+gkrellm_panel_label_on_top_of_decals(GkrellmPanel *p, gboolean mode)
+	{
+	if (p)
+		p->label_on_top_of_decals = mode;
+	}
+
 void
 gkrellm_draw_panel_label(GkrellmPanel *p)
 	{
-	draw_panel(p, TRUE);
+	if (p)
+		draw_panel(p, TRUE);
 	}
 
 void
@@ -601,6 +616,8 @@ gkrellm_draw_panel_layers(GkrellmPanel *p)
 	if (p->modified)
 		{
 		do_top_layer_decals = push_decal_pixmaps(p, FALSE);
+		if (p->label_on_top_of_decals)
+			draw_panel_label(p, FALSE);
 		push_krell_pixmaps(p);
 		if (do_top_layer_decals)
 			push_decal_pixmaps(p, TRUE);
@@ -615,6 +632,7 @@ gkrellm_draw_panel_layers(GkrellmPanel *p)
 					0, 0,   0, 0,   p->w, p->h);
 		else
 #endif
+
 		drawable = p->drawing_area->window;
 		for (list = p->decal_list; list; list = list->next)
 			{
