@@ -157,6 +157,22 @@ gkrellm_scale_pixbuf_to_pixmap(GdkPixbuf *src_pixbuf, GdkPixmap **pixmap,
 	return TRUE;
 	}
 
+static void
+fix_border_overlap(gint *a, gint *b, gint l)
+	{
+	gint	A = 0, B = 0;
+	gint	lb;
+
+	lb = *a + *b;
+	if (l > 1 && lb > 0)
+		{
+		A = *a * (l - 1) / lb;
+		B = *b * (l - 1) / lb;
+		}
+	*a = A;
+	*b = B;
+	}
+
 GdkPixbuf *
 gkrellm_scale_piximage_to_pixbuf(GkrellmPiximage *piximage,
 			gint w_dst, gint h_dst)
@@ -189,9 +205,9 @@ gkrellm_scale_piximage_to_pixbuf(GkrellmPiximage *piximage,
 	dst_pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, has_alpha, 8, w_dst,h_dst);
 
 	if (b.left + b.right >= w_dst || b.left + b.right >= w_src)
-		b.left = b.right = 0;
+		fix_border_overlap(&b.left, &b.right, (w_dst > w_src) ? w_src : w_dst);
 	if (b.top + b.bottom >= h_dst || b.top + b.bottom >= h_src)
-		b.top = b.bottom = 0;
+		fix_border_overlap(&b.top, &b.bottom, (h_dst > h_src) ? h_src : h_dst);
 
 	/* Corner areas are not scaled
 	*/
@@ -446,17 +462,17 @@ gkrellm_scale_theme_background(GkrellmPiximage *piximage, GdkPixmap **pixmap,
 
 	bdr = piximage->border;
 	if (bdr.left + bdr.right >= w_src)
-		bdr.left = bdr.right = 0;
+		fix_border_overlap(&bdr.left, &bdr.right, w_src);
 	if (bdr.top + bdr.bottom >= h_src)
-		bdr.top = bdr.bottom = 0;
+		fix_border_overlap(&bdr.top, &bdr.bottom, h_src);
 	l = bdr.left * _GK.theme_scale / 100;
 	r = bdr.right * _GK.theme_scale / 100;
 	t = bdr.top * _GK.theme_scale / 100;
 	b = bdr.bottom * _GK.theme_scale / 100;
 	if (l + r >= w_dst)
-		l = r = 0;
+		fix_border_overlap(&l, &r, w_dst);
 	if (t + b >= h_dst)
-		t = b = 0;
+		fix_border_overlap(&t, &b, h_dst);
 
 	interp_type = GDK_INTERP_BILINEAR;
 
