@@ -767,11 +767,12 @@ gkrellm_place_plugin(GList **monitor_list, GkrellmMonitor *plugin)
 GkrellmMonitor *
 install_plugin(gchar *plugin_name)
 	{
-	GList			*list;
-	GModule			*module;
-	GkrellmMonitor	*m, *mm;
-	GkrellmMonitor	*(*init_plugin)();
-	gchar			buf[256];
+	GList					*list;
+	GModule					*module;
+	GkrellmMonitor			*m, *mm;
+	GkrellmMonitor			*(*init_plugin)();
+	gchar					buf[256];
+	static GkrellmMonitor	mon_tmp;
 
 	if (!g_module_supported())
 		return NULL;
@@ -793,12 +794,21 @@ install_plugin(gchar *plugin_name)
 		return NULL;
 		}
 	_GK.no_messages = TRUE;		/* Enforce policy */
+
+	mon_tmp.name = g_strdup(plugin_name);
+	gkrellm_record_state(INIT_MONITOR, &mon_tmp);
+
 #if !defined(WIN32)
 	m = (*init_plugin)();
 #else
 	m = (*init_plugin)(callbacks);
 #endif
 	_GK.no_messages = FALSE;
+
+	g_free(mon_tmp.name);
+	mon_tmp.name = NULL;
+	gkrellm_record_state(INTERNAL, NULL);
+
 	if (m == NULL)
 		{
 		plugin_log(_("\tOoops! plugin returned NULL, aborting\n"), NULL);
@@ -1022,11 +1032,22 @@ save_plugins_enable_file(void)
 	g_free(path);
 	}
 
+static gchar *
+string_suffix(gchar *string, gchar *suffix)
+	{
+	gchar	*dot;
+
+	dot = strrchr(string, '.');
+	if (dot && !strcmp(dot + 1, suffix))
+		return dot + 1;
+	return NULL;
+	}
+
 static void
 scan_for_plugins(gchar *path)
 	{
     GDir			*dir;
-    gchar			*name;
+    gchar			*name, *filename;
 	GList			*list;
 	GkrellmMonitor	*m = NULL;
 	gchar			*s;
@@ -1036,6 +1057,20 @@ scan_for_plugins(gchar *path)
 		return;
 	while ((name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
+		/* If there's a libtool .la archive, won't want to load this .so
+		*/
+		if (   !string_suffix(name, "la")
+			&& (s = strrchr(name, '.')) != NULL
+		   )
+			{
+			s = g_strndup(name, s - name);
+			filename = g_strconcat(path, G_DIR_SEPARATOR_S, s, ".la", NULL);
+			exists = g_file_test(filename, G_FILE_TEST_EXISTS);
+			g_free(s);
+			g_free(filename);
+			if (exists)
+				continue;
+			}
 		for (list = plugins_list; list; list = list->next)
 			{
 			m = (GkrellmMonitor *) list->data;
