@@ -219,7 +219,7 @@ gkrellm_sys_mem_read_data(void)
    unsigned long	total, used, x_used, free, shared, buffers, cached;
    struct vmtotal vmt;
    struct uvmexp uvmexp;
-   int len;
+   size_t len;
    static struct nlist nl[] = {
 #define X_UVM_EXP    0
    { "_uvmexp" },
@@ -291,7 +291,7 @@ gkrellm_sys_mem_init(void)
 /* Battery monitor interface */
 #include <sys/ioctl.h>
 
-#if defined(__i386__)
+#if defined(__i386__) || defined(__powerpc__)
 
 #include <machine/apmvar.h>
 #define	APMDEV		"/dev/apm"
