@@ -1127,10 +1127,7 @@ gkrellm_sys_mem_read_data(void)
 		else if (buf[0] == 'S')
 			{
 			if (!strncmp(buf, "Swap:", 5))
-				{
 				sscanf(buf + 6,"%Lu %Lu", &swap_total, &swap_used);
-				break;
-				}
 			else if (!strncmp(buf, "SwapTotal:", 10))
 				tagged_format_meminfo(buf + 11, &swap_total);
 			else if (!strncmp(buf, "SwapFree:", 9))
@@ -2196,7 +2193,7 @@ sysfs_sensors_init(void)
 		while ((name = (gchar *) g_dir_read_name(chip_dir)) != NULL)
 			{
 			if (   (s = strstr(name, "_input")) == NULL
-				|| s - name > 4 || !isdigit(*(s + 6))
+				|| s - name > 4 || (strlen(s) > 6 && !isdigit(*(s + 6)))
 			   )
 				continue;
 			strncpy(buf, name, s - name);
