@@ -34,7 +34,7 @@ gkrellm_sys_main_init(void)
 	|  kmem privilege, it runs with available information.
 	*/
 	kvmd = kvm_openfiles(NULL, NULL, NULL, O_RDONLY, errbuf);
-	if (setgid(getgid()) != 0)
+	if (setgid(getegid()) != 0)
 		{
 		fprintf(stderr, "Can't drop setgid privileges.");
 		exit(1);
@@ -107,8 +107,9 @@ gkrellm_sys_proc_read_data(void)
    double avenrun;
 	guint	n_forks = 0, n_processes = 0;
    struct uvmexp *uvmexp;
-   int len, i;
-	
+   int i;
+   size_t len;
+
 	static struct nlist nl[] = {
 #define X_UVM_EXP    0
 	   { "_uvmexp" },
