@@ -844,13 +844,15 @@ gkrellm_sys_mem_read_data() {
         physpages = sysconf(_SC_PHYS_PAGES);
     }
 
-    total = physpages << pageshift;
+    total = physpages;
+    total <<= pageshift;
 
     ksp = kstat_lookup(kc, "unix", -1, "system_pages");
     if (ksp && kstat_read(kc, ksp, NULL) >= 0) {
         knp = (kstat_named_t *)kstat_data_lookup(ksp, "pagesfree");
         if (knp) {
-            free = knp->value.ui32 << pageshift;
+            free = knp->value.ui32;
+            free <<= pageshift;
             used = total - free;
         }
     }
@@ -858,13 +860,14 @@ gkrellm_sys_mem_read_data() {
     if (swapctl(SC_AINFO, &ai) == -1) {
         perror("swapctl");
     }
-    swap_total = ai.ani_max << pageshift;
-    swap_used  = ai.ani_resv << pageshift;
+	swap_total = ai.ani_max;
+	swap_total <<= pageshift;
+
+    swap_used  = ai.ani_resv;
+    swap_used  <<= pageshift;
 
     /* NEED TO BE COMPLETED
-     * mem.total, mem.used, (they are used in memory meter)
-     * mem.x_used, mem.free, mem.shared, mem.buffers, mem.cached 
-     * swap.total, swap.used (they are used in swap meter) 
+     * mem.x_used, mem.shared, mem.buffers, mem.cached 
      * swap_chart.page_in, swap_chart.page_out (for swap pages in/out chart) 
      */ 
 
